===================
Search For Anything
===================

.. toctree::
    :maxdepth: 2
    :caption: Contents:

Overview
--------

This screen is used to search the Peek database.

Searches can be performed with the following criteria :

- Whole or Parial Keywords
- An object type, or all object types.
- The property name that contains the keyword, or all property names.

Peeks Search functionality can be used to find:

- Jobs
- Operations
- Incidents
- Equipment

How to Search
-------------

#. Click on the **Search for Anything** button on the Navigation Bar.

.. image:: search_button.png
    :align: center

----

#. Enter a **Keyword** into the search bar.
#. Select the **Object** type.
#. Select your search result.

.. image:: search_popup.png
    :align: center

Filtering Search Results
------------------------

#. Click the filter button
#. Click on the **Property** or **Object Type** to view the dropdown menu.
#. Click on your filter attribute.

.. image:: search_filtered.png
    :align: center

.. note::
    Clicking on an object in the search results will display an **Information
    Popup**.
 
